==> ansible-12.0.0.tgz: lib/python3.12/site-packages/ansible_collections/cisco/meraki/plugins/modules/networks_clients_splash_authorization_status_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: networks_clients_splash_authorization_status_info
short_description: Information module for networks _clients _splash _authorization _status
description:
  - Get all networks _clients _splash _authorization _status. - > Return the splash authorization for a client, for each SSID they've associated
    with through splash. Only enabled SSIDs with Click-through splash enabled will be included. Clients can be identified by a client key or either
    the MAC or IP depending on whether the network uses Track-by-IP.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
      - NetworkId path parameter. Network ID.
    type: str
  clientId:
    description:
      - ClientId path parameter. Client ID.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for networks getNetworkClientSplashAuthorizationStatus
    description: Complete reference of the getNetworkClientSplashAuthorizationStatus API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-network-client-splash-authorization-status
notes:
  - SDK Method used are
    networks.Networks.get_network_client_splash_authorization_status,
  - Paths used are
    get /networks/{networkId}/clients/{clientId}/splashAuthorizationStatus,
"""

EXAMPLES = r"""
- name: Get all networks _clients _splash _authorization _status
  cisco.meraki.networks_clients_splash_authorization_status_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    networkId: string
    clientId: string
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "0": {
        "authorizedAt": "string",
        "expiresAt": "string",
        "isAuthorized": true
      }
    }
"""

==> ansible-13.3.0.tgz: lib/python3.13/site-packages/ansible_collections/cisco/meraki/plugins/modules/networks_clients_splash_authorization_status_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: networks_clients_splash_authorization_status_info
short_description: Information module for networks _clients _splashauthorizationstatus
description:
  - Information module for Networks Clients Splashauthorizationstatus Info.
  - Get all networks _clients _splashauthorizationstatus.
  - >
    Return the splash authorization for a client, for each SSID they've associated
    with through splash. Only enabled SSIDs with Click-through splash enabled will
    be included. Clients can be identified by a client key or either the MAC or IP
    depending on whether the network uses Track-by-IP.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
      - Information module for Networks Clients Splashauthorizationstatus Info.
      - NetworkId path parameter. Network ID.
    type: str
  clientId:
    description:
      - Information module for Networks Clients Splashauthorizationstatus Info.
      - ClientId path parameter. Client ID.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for networks getNetworkClientSplashAuthorizationStatus
    description: Complete reference of the getNetworkClientSplashAuthorizationStatus
      API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-network-client-splash-authorization-status
notes:
  - SDK Method used are
    networks.Networks.get_network_client_splash_authorization_status,
  - Paths used are
    get /networks/{networkId}/clients/{clientId}/splashAuthorizationStatus,
"""

EXAMPLES = r"""
- name: Get all networks _clients _splashauthorizationstatus
  cisco.meraki.networks_clients_splash_authorization_status_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    networkId: string
    clientId: string
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample:
  - {}
"""
